require "draw"
require "load"

function love.load()
    love.graphics.setBackgroundColor( 255, 255, 255 )
    --love.graphics.setDefaultImageFilter("nearest", "nearest")

    winW=love.graphics.getWidth()
    winH=love.graphics.getHeight()
    size = 80
    sc = 4

    map = loadMap(1)
    bg = love.graphics.newImage("/graphics/background.png")
    ps1 = love.graphics.newImage("/graphics/ps1.png")
    ps2 = love.graphics.newImage("/graphics/ps2.png")

    bgscrolling = {{img = ps2,speed = 0.1, x=0,y=180},{img = ps1, speed = 0.3, x = 150, y =180}}

    black = love.graphics.newImage("/graphics/corners.png")
    cloud = love.graphics.newImage("/graphics/cloud.png")
    

    font = love.graphics.newFont(20)
    love.graphics.setFont(font)
    
	
    clocks = {}
    for x = 500, 900, 200 do
        addClock(x)
    end

    imageTiles = love.graphics.newImage("/graphics/tiles.png")
    wholeW = imageTiles:getWidth()
    wholeH = imageTiles:getHeight()

    tileQuads = constructQuadData(imageTiles,size)

    player = {x = 300, y = 300, time=10, animation= {}, frame = 1, falling = true,k = 0, moving = false, dir = 1}

    --lets load the animation
    local lframe = 1
    while love.filesystem.exists("/graphics/bomb/robot-".. lframe ..".png") do
        print("inserting ".." /graphics/bomb/robot-".. lframe ..".png")
		table.insert(player.animation, love.graphics.newImage("/graphics/bomb/robot-".. lframe ..".png"))
		lframe = lframe + 1
	end

    --environment displacement
    dispx = 0

    clouds = {}
    table.insert(clouds, newCloud(600))

end

function addClock(x)
    local clock = {}
    clock.x = x
    clock.y = math.random(340,540)
    
    table.insert(clocks, clock)
end


function love.update(dt)
    player.moving = false
    if love.keyboard.isDown("right") then
        player.moving = true
        player.dir = 1
        if player.x < 480 then
            player.x = player.x + 175*dt
        else
            player.x = 480
            dispx = dispx + 175*dt
        end
    end

    if love.keyboard.isDown("left") then
        player.moving = true
        player.dir = -1
        if player.x > 320 or dispx <= 1 then
            player.x = player.x - 175*dt
        else
            player.x = 320
            dispx = dispx - 175*dt
        end
    end
    
    if player.falling then
        player.y = player.y + 100*dt*player.k
        player.k = player.k + 3*dt
    end

    if player.moving then
        player.frame = player.frame + 9*dt
        if player.frame >= 9 then player.frame = player.frame - 8 end
    end


    player.time = player.time-1*dt

    collY()
end

function collY()
    local testX = mf((player.x+dispx)/size)+1
    local testY = mf(player.y/size)+1
    if testY > 0 and testY <= 9 then
    if testX > 0 then
        if map[testY+1][testX] > 0 then
            player.falling = false
            player.k=0
        end
    end
    end
end

function newCloud(a)
    local c = {x=a,y= math.random(50,300),alpha = math.random(255,255),scale = math.random(80,120)/100}
    return c
end

function mf(t) 
    t = math.floor(t)
    return t
end

function love.draw() 
    love.graphics.setBlendMode("alpha")
    love.graphics.draw(bg,0,0,0)

    drawClouds()

    drawScrolling()

    drawMap()
    
    
    if player.dir == 1 then love.graphics.draw(player.animation[mf(player.frame)],mf(player.x),mf(player.y)-20,0,player.dir,1) end
    if player.dir == -1 then love.graphics.draw(player.animation[mf(player.frame)],mf(player.x)+80,mf(player.y)-20,0,player.dir,1) end

    drawTimer()

    love.graphics.setBlendMode("multiplicative")
    love.graphics.setColor(255,255,255,255)
    love.graphics.draw(black,player.x-100*sc*2+150,player.y-100*sc*2+150,0,sc*2,sc*2)
end




function love.keypressed(key)
    if key == "up" and not player.falling then
        player.k = -3
        player.falling = true
    end
end

function love.mousepressed(x, y, button)

end